@@ -466,11 +466,24 @@ class ClUpdateAction(Action):
          },
          {'name': 'update:set_current_level',
          'method': 'Update.update_increment_current_level()',
-         'depend': (Tasks.success() & Tasks.hasnot("interrupt") & Tasks.success_all("update")), 
+         'depend': (Tasks.success() & Tasks.hasnot("interrupt") &
+             Tasks.success_all("update") & Tasks.hasnot("check_schedule")), 
          'condition': lambda Get: Get('cl_update_sync_only_set') == 'off' and
                 Get('cl_update_pretend_set') == 'off' and
                 Get('update.cl_update_use_migration_host') == 'on'
          },
+         {'name': 'update_world:set_latest_tag',
+         'method': 'Update.update_set_current_saved_tag()',
+         'depend': (Tasks.success() & Tasks.hasnot("interrupt") &
+             Tasks.success_all("update") & Tasks.hasnot("check_schedule")), 
+         'condition': lambda Get: Get('cl_update_sync_only_set') == 'off' and
+                Get('cl_update_pretend_set') == 'off'
+         },
+        {'name': 'clear_migration_host',
+         'method': 'Update.delete_binhost()',
+         'depend': (Tasks.hasnot("check_schedule")), 
+         'condition': lambda Get: Get('update.cl_update_use_migration_host') == 'on'
+         },
         # сообщение удачного завершения при обновлении ревизии
         {'name': 'success_rev',
          'message': __("System update finished!"),
